"""
PyPantry

An API wrapper for Pantry json database
"""

__version__ = "0.1.0"
__author__ = 'Stephen Hudson'
__credits__ = 'Argonne National Laboratory'

from .main import PyPantry
from .basket import PyPantryBasket


import requests
import json

class PyPantry:
    def __init__(self, pantryID:str):
        self.pantryID = pantryID
        self.url = f"https://getpantry.cloud/apiv1/pantry/{self.pantryID}"
    
    def get(self):
        headers = {
        'Content-Type': 'application/json'
        }
        response = requests.request("GET", self.url, headers=headers, data="")
        return json.loads(response.text)
    
    def post(self, basket:str, data:dict):
        payload = json.dumps(data)
        headers = {
            'Content-Type': 'application/json'
        }
        response = requests.request("POST", self.url+f"/basket/{basket}", headers=headers, data=payload)
        print(response.text)


import requests
import json
from . import PyPantry

class PyPantryBasket:
    def __init__(self, pantry:PyPantry, basket:str):
        self.url = pantry.url+f"/basket/{basket}"
    
    def find(self, query:dict=None):
        headers = {
            'Content-Type': 'application/json'
        }
        response = requests.request("GET", self.url, headers=headers, data="")
        try:
            data = json.loads(response.text)
        except:
            data = {}
        e, f = {}, {}
        if query:
            for key in data.keys():
                if key in query.keys():
                    e[key] = data[key]
            for value in e.values():
                if value in query.values():
                    key = list(e.keys())[list(e.values()).index(value)]
                    f[key] = value
            return f
        else:
            return data
    
    def insert(self, key:str, value):
        data = self.find()
        data[key] = value
        payload = json.dumps(data)
        headers = {
            'Content-Type': 'application/json'
        }
        response = requests.request("POST", self.url, headers=headers, data=payload)


from setuptools import setup

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()
    
setup(
    name='PyPantry',
    version='0.1.0',    
    description='An API wrapper for Pantry json database',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/studiousgamer/PyPantry',
    author='Studious Gamer',
    author_email="natyavidhanbiswas10@gmail.com",
    project_urls={
        "Bug Tracker": "https://github.com/studiousgamer/PyPantry/issues",
    },
    license='MIT Licence',
    packages=['PyPantry'],
    install_requires=['requests'],

    classifiers=[
        'License :: OSI Approved :: MIT License',  
        "Operating System :: OS Independent",
        'Programming Language :: Python :: 3',
    ],
)